package com.yanzhu.manage.service;

import java.util.List;
import com.yanzhu.manage.domain.BusExamUser;

/**
 * 用户试卷Service接口
 * 
 * @author JiangYuQi
 * @date 2024-08-25
 */
public interface IBusExamUserService 
{
    /**
     * 查询用户试卷
     * 
     * @param id 用户试卷主键
     * @return 用户试卷
     */
    public BusExamUser selectBusExamUserById(Long id);

    /**
     * 查询用户试卷列表
     * 
     * @param busExamUser 用户试卷
     * @return 用户试卷集合
     */
    public List<BusExamUser> selectBusExamUserList(BusExamUser busExamUser);

    /**
     * 新增用户试卷
     * 
     * @return 结果
     */
    public BusExamUser insertBusExamUser();

    /**
     * 修改用户试卷
     * 
     * @param busExamUser 用户试卷
     * @return 结果
     */
    public int updateBusExamUser(BusExamUser busExamUser);

    /**
     * 批量删除用户试卷
     * 
     * @param ids 需要删除的用户试卷主键集合
     * @return 结果
     */
    public int deleteBusExamUserByIds(Long[] ids);

    /**
     * 删除用户试卷信息
     * 
     * @param id 用户试卷主键
     * @return 结果
     */
    public int deleteBusExamUserById(Long id);
}
